@@ -57,17 +57,6 @@ void list_sub_window_update(GtkMenuItem *item, gpointer user_data);
 void list_sub_window_focus(GtkMenuItem *item, gpointer user_data);
 void list_sub_window_focus_all(GtkMenuItem *item, gpointer user_data);
 void list_sub_window_add_focus(GtkMenuItem *item, gpointer user_data);
-
-void tree_sub_window_delete(GtkMenuItem *item, gpointer user_data);
-void tree_sub_window_copy(GtkMenuItem *item, gpointer user_data);
-void tree_sub_window_move_top(GtkMenuItem *item, gpointer user_data);
-void tree_sub_window_move_last(GtkMenuItem *item, gpointer user_data);
-void tree_sub_window_move_up(GtkMenuItem *item, gpointer user_data);
-void tree_sub_window_move_down(GtkMenuItem *item, gpointer user_data);
-void tree_sub_window_update(GtkMenuItem *item, gpointer user_data);
-void tree_sub_window_hide(GtkMenuItem *item, gpointer user_data);
-void tree_sub_window_focus(GtkMenuItem *item, gpointer user_data);
-void tree_sub_window_add_focus(GtkMenuItem *item, gpointer user_data);
 void update_viewer(struct obj_list_data *d);
 
 GtkWidget *sub_win_create_popup_menu(struct obj_list_data *d, int n, struct subwin_popup_list *list, GCallback cb);
