@@ -49,8 +49,10 @@ enum paper_id {
   PAPER_ID_B5,
   PAPER_ID_LETTER,
   PAPER_ID_LEGAL,
+  PAPER_ID_EXECUTIVE,
   PAPER_ID_NORMAL,
   PAPER_ID_WIDE,
+  PAPER_ID_WIDE2,
   PAPER_ID_CUSTOM,
 };
 
@@ -119,7 +121,8 @@ struct menulocal
   int use_custom_palette;
   struct narray custom_palette;
   char *source_style_id;
-  int math_input_mode;
+  int math_input_mode, use_dark_theme;
+  int default_axis_width, default_axis_height;
 };
 
 extern struct menulocal Menulocal;
@@ -155,7 +158,9 @@ void initwindowconfig(void);
 int mgtkwindowconfig(void);
 void menuadddrawrable(struct objlist *parent, struct narray *drawrable);
 int menu_save_config(int type);
+void menu_use_dark_theme_set(int state);
 void main_window_redraw(void);
 void init_layer(const char *obj);
+void menu_default_axis_size(struct menulocal *local);
 
 #endif
