@@ -1395,7 +1395,6 @@ LoadNgpFile(char *file, int console, char *option)
   char *argv[2];
   struct narray sarray;
   char mes[256];
-  int sec;
   N_VALUE *inst;
   struct objlist *robj;
   int idn;
@@ -1444,6 +1443,7 @@ LoadNgpFile(char *file, int console, char *option)
     if (arrayadd(&sarray, &s) == NULL) {
       g_free(s);
       arraydel2(&sarray);
+      delobj(obj, newid);
       return 1;
     }
   }
@@ -1452,12 +1452,14 @@ LoadNgpFile(char *file, int console, char *option)
 
   if (name == NULL) {
     arraydel2(&sarray);
+    delobj(obj, newid);
     return 1;
   }
 
   if (arrayadd(&sarray, &name) == NULL) {
     g_free(name);
     arraydel2(&sarray);
+    delobj(obj, newid);
     return 1;
   }
 
@@ -1467,10 +1469,7 @@ LoadNgpFile(char *file, int console, char *option)
     allocnow = allocate_console();
   }
 
-  sec = TRUE;
-  argv[0] = (char *) &sec;
-  argv[1] = NULL;
-  _exeobj(obj, "security", inst, 1, argv);
+  exeobj(obj, "set_security", newid, 0, NULL);
 
   argv[0] = (char *) &sarray;
   argv[1] = NULL;
@@ -1487,11 +1486,6 @@ LoadNgpFile(char *file, int console, char *option)
   unregisterevloop(robj, idn, Menulocal.inst);
   menu_lock(FALSE);
 
-  sec = FALSE;
-  argv[0] = (char *) &sec;
-  argv[1] = NULL;
-  _exeobj(obj, "security", inst, 1, argv);
-
   if (r == 0) {
     struct objlist *aobj;
     int i;
@@ -1859,8 +1853,9 @@ SetFileHidden(void)
   r = 0;
   SelectDialog(&DlgSelect, fobj, NULL, FileCB, &farray, &ifarray);
   if (DialogExecute(TopLevel, &DlgSelect) == IDOK) {
-    int num, inum, *array;
+    int num, inum, *array, undo, modified = FALSE;
     a = TRUE;
+    undo = menu_save_undo_single(UNDO_TYPE_EDIT, "data");
     for (i = 0; i <= lastinst; i++) {
       putobj(fobj, "hidden", i, &a);
     }
@@ -1873,16 +1868,21 @@ SetFileHidden(void)
 
     inum = arraynum(&ifarray);
     if (inum != num) {
-      set_graph_modified();
+      modified = TRUE;
     } else {
       for (i = 0; i < num; i++) {
 	if (arraynget_int(&ifarray, i) != array[i]) {
-	  set_graph_modified();
+	  modified = TRUE;
 	  break;
 	}
       }
     }
     r = 1;
+    if (modified) {
+      set_graph_modified();
+    } else {
+      menu_undo_internal(undo);
+    }
   }
 
   arraydel(&ifarray);
