@@ -66,25 +66,22 @@ struct pagelisttype
 {
   char *paper, *name;
   enum paper_id id;
-  int langscape, width, height;
+  int width, height;
 };
 
 static struct pagelisttype pagelist[] = {
-  {N_("Custom"),                   "custom",              PAPER_ID_CUSTOM, TRUE,  0,     0},
-  {N_("normal display (4:3)"), "normal display",      PAPER_ID_NORMAL, TRUE,  28000, 21000},
-  {N_("wide display (16:9)"),  "wide display",        PAPER_ID_WIDE,   TRUE,  38400, 21600},
-  {"A3 P (297.00x420.00)",     GTK_PAPER_NAME_A3,     PAPER_ID_A3,     FALSE, 29700, 42000},
-  {"A4 P (210.00x297.00)",     GTK_PAPER_NAME_A4,     PAPER_ID_A4,     FALSE, 21000, 29700},
-  {"A4 L (297.00x210.00)",     GTK_PAPER_NAME_A4,     PAPER_ID_A4,     TRUE,  29700, 21000},
-  {"A5 P (148.00x210.00)",     GTK_PAPER_NAME_A5,     PAPER_ID_A5,     FALSE, 14800, 21000},
-  {"A5 L (210.00x148.00)",     GTK_PAPER_NAME_A5,     PAPER_ID_A5,     TRUE,  21000, 14800},
-  {"B4 P (257.00x364.00)",     "iso_b4",              PAPER_ID_B4,     FALSE, 25700, 36400},
-  {"B5 P (182.00x257.00)",     GTK_PAPER_NAME_B5,     PAPER_ID_B5,     FALSE, 18200, 25700},
-  {"B5 L (257.00x182.00)",     GTK_PAPER_NAME_B5,     PAPER_ID_B5,     TRUE,  25700, 18200},
-  {N_("Letter P (215.90x279.40)"), GTK_PAPER_NAME_LETTER, PAPER_ID_LETTER, FALSE, 21590, 27940},
-  {N_("Letter L (279.40x215.90)"), GTK_PAPER_NAME_LETTER, PAPER_ID_LETTER, TRUE,  27940, 21590},
-  {N_("Legal  P (215.90x355.60)"), GTK_PAPER_NAME_LEGAL,  PAPER_ID_LEGAL,  FALSE, 21590, 35560},
-  {N_("Legal  L (355.60x215.90)"), GTK_PAPER_NAME_LEGAL,  PAPER_ID_LEGAL,  TRUE,  35560, 21590},
+  {N_("Custom"),                  "custom",                 PAPER_ID_CUSTOM,    0,     0},
+  {N_("normal display (4:3)"),    "normal display",         PAPER_ID_NORMAL,    21000, 28000},
+  {N_("wide display (16:9)"),     "wide display",           PAPER_ID_WIDE,      21600, 38400},
+  {N_("wide display (16:10)"),    "wide display",           PAPER_ID_WIDE2,     21000, 33600},
+  {"A3 (297.00x420.00)",          GTK_PAPER_NAME_A3,        PAPER_ID_A3,        29700, 42000},
+  {"A4 (210.00x297.00)",          GTK_PAPER_NAME_A4,        PAPER_ID_A4,        21000, 29700},
+  {"A5 (148.00x210.00)",          GTK_PAPER_NAME_A5,        PAPER_ID_A5,        14800, 21000},
+  {"B4 (257.00x364.00)",          "iso_b4",                 PAPER_ID_B4,        25700, 36400},
+  {"B5 (182.00x257.00)",          GTK_PAPER_NAME_B5,        PAPER_ID_B5,        18200, 25700},
+  {N_("Letter (215.90x279.40)"),  GTK_PAPER_NAME_LETTER,    PAPER_ID_LETTER,    21590, 27940},
+  {N_("Legal (215.90x355.60)"),   GTK_PAPER_NAME_LEGAL,     PAPER_ID_LEGAL,     21590, 35560},
+  {N_("Executive (184.2x266.7)"), GTK_PAPER_NAME_EXECUTIVE, PAPER_ID_EXECUTIVE, 18420, 26670},
 };
 
 #define PAGELISTNUM (sizeof(pagelist) / sizeof(*pagelist))
@@ -94,6 +91,7 @@ int
 set_paper_type(int w, int h)
 {
   unsigned int j;
+  int landscape = FALSE;
 
   if (w < 1 || h < 1)
     return 0;
@@ -103,6 +101,10 @@ set_paper_type(int w, int h)
 
   for (j = 0; j < PAGELISTNUM; j++) {
     if (w == pagelist[j].width &&  h == pagelist[j].height) {
+      landscape = FALSE;
+      break;
+    } else if (h == pagelist[j].width &&  w == pagelist[j].height) {
+      landscape = TRUE;
       break;
     }
   }
@@ -113,7 +115,7 @@ set_paper_type(int w, int h)
 
   Menulocal.PaperName = pagelist[j].name;
   Menulocal.PaperId = pagelist[j].id;
-  Menulocal.PaperLandscape = pagelist[j].langscape;
+  Menulocal.PaperLandscape = landscape;
 
   return j;
 }
@@ -126,13 +128,19 @@ PageDialogSetupItem(GtkWidget *w, struct PageDialog *d)
   spin_entry_set_val(d->leftmargin, Menulocal.LeftMargin);
   spin_entry_set_val(d->topmargin, Menulocal.TopMargin);
 
-  spin_entry_set_val(d->paperwidth, Menulocal.PaperWidth);
-  spin_entry_set_val(d->paperheight, Menulocal.PaperHeight);
-
   spin_entry_set_val(d->paperzoom, Menulocal.PaperZoom);
 
   j = set_paper_type(Menulocal.PaperWidth, Menulocal.PaperHeight);
 
+  if (Menulocal.PaperLandscape) {
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(d->landscape), TRUE);
+  } else {
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(d->portrait), TRUE);
+  }
+
+  spin_entry_set_val(d->paperwidth, Menulocal.PaperWidth);
+  spin_entry_set_val(d->paperheight, Menulocal.PaperHeight);
+
   combo_box_set_active(d->paper, j);
   combo_box_set_active(d->decimalsign, Menulocal.Decimalsign);
 }
@@ -141,24 +149,44 @@ static void
 PageDialogPage(GtkWidget *w, gpointer client_data)
 {
   struct PageDialog *d;
-  int a;
+  int paper, landscape;
 
   d = (struct PageDialog *) client_data;
 
-  a = combo_box_get_active(d->paper);
+  paper = combo_box_get_active(d->paper);
+  landscape = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(d->landscape));
 
-  if (a < 0)
+  if (paper < 0)
     return;
 
-  set_widget_sensitivity_with_label(d->paperwidth, a == 0);
-  set_widget_sensitivity_with_label(d->paperheight, a == 0);
+  set_widget_sensitivity_with_label(d->paperwidth, paper == 0);
+  set_widget_sensitivity_with_label(d->paperheight, paper == 0);
 
-  if (a > 0) {
-    spin_entry_set_val(d->paperwidth, pagelist[a].width);
-    spin_entry_set_val(d->paperheight, pagelist[a].height);
+  if (paper > 0) {
+    if (landscape) {
+      spin_entry_set_val(d->paperwidth, pagelist[paper].height);
+      spin_entry_set_val(d->paperheight, pagelist[paper].width);
+    } else {
+      spin_entry_set_val(d->paperwidth, pagelist[paper].width);
+      spin_entry_set_val(d->paperheight, pagelist[paper].height);
+    }
   }
 }
 
+static void
+PageDialogOrientation(GtkWidget *widget, gpointer client_data)
+{
+  struct PageDialog *d;
+  int w, h;
+
+  d = (struct PageDialog *) client_data;
+
+  w = spin_entry_get_val(d->paperwidth);
+  h = spin_entry_get_val(d->paperheight);
+  spin_entry_set_val(d->paperwidth, h);
+  spin_entry_set_val(d->paperheight, w);
+}
+
 static void
 PageDialogSetup(GtkWidget *wi, void *data, int makewidget)
 {
@@ -192,6 +220,16 @@ PageDialogSetup(GtkWidget *wi, void *data, int makewidget)
       combo_box_append_text(d->paper, _(pagelist[j].paper));
     }
 
+    w = gtk_radio_button_new_with_mnemonic(NULL, _("_Portrait"));
+    add_widget_to_table(table, w, _("_Orientation:"), FALSE, i++);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), TRUE);
+    d->portrait = w;
+
+    w = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(w), _("L_andscape"));
+    add_widget_to_table_sub(table, w, NULL,FALSE, 1, 1, 1, i++);
+    d->landscape = w;
+    g_signal_connect(w, "toggled", G_CALLBACK(PageDialogOrientation), d);
+
     w = create_spin_entry_type(SPIN_BUTTON_TYPE_POSITION, FALSE, TRUE);
     add_widget_to_table(table, w, _("_Left margin:"), FALSE, i++);
     d->leftmargin = w;
@@ -217,6 +255,7 @@ PageDialogSetup(GtkWidget *wi, void *data, int makewidget)
     gtk_widget_show_all(GTK_WIDGET(d->vbox));
   }
   PageDialogSetupItem(wi, d);
+  d->show_cancel = ! d->new_graph;
 }
 
 static void
@@ -247,10 +286,11 @@ PageDialogClose(GtkWidget *wi, void *data)
 }
 
 void
-PageDialog(struct PageDialog *data)
+PageDialog(struct PageDialog *data, int new_graph)
 {
   data->SetupWindow = PageDialogSetup;
   data->CloseWindow = PageDialogClose;
+  data->new_graph = new_graph;
 }
 
 static void
@@ -325,8 +365,7 @@ SwitchDialogAdd(GtkWidget *w, gpointer client_data)
   }
 
   if (list) {
-    g_list_foreach(list, free_tree_path_cb, NULL);
-    g_list_free(list);
+    g_list_free_full(list, (GDestroyNotify) gtk_tree_path_free);
   }
 
   SwitchDialogSetupItem(d->widget, d);
@@ -354,8 +393,7 @@ SwitchDialogInsert(GtkWidget *w, gpointer client_data)
       ptr = gtk_tree_path_get_indices((GtkTreePath *)(last->data));
       pos = ptr[0];
     }
-    g_list_foreach(list, free_tree_path_cb, NULL);
-    g_list_free(list);
+    g_list_free_full(list, (GDestroyNotify) gtk_tree_path_free);
   }
 
   data = arraydata(&(d->idrawrable));
@@ -379,8 +417,7 @@ SwitchDialogInsert(GtkWidget *w, gpointer client_data)
   }
 
   if (list) {
-    g_list_foreach(list, free_tree_path_cb, NULL);
-    g_list_free(list);
+    g_list_free_full(list, (GDestroyNotify) gtk_tree_path_free);
   }
 
   SwitchDialogSetupItem(d->widget, d);
@@ -482,8 +519,7 @@ SwitchDialogUp(GtkWidget *w, gpointer client_data)
     }
   }
 
-  g_list_foreach(list, free_tree_path_cb, NULL);
-  g_list_free(list);
+  g_list_free_full(list, (GDestroyNotify) gtk_tree_path_free);
 }
 
 static void
@@ -540,8 +576,7 @@ SwitchDialogDown(GtkWidget *w, gpointer client_data)
     }
   }
 
-  g_list_foreach(list, free_tree_path_cb, NULL);
-  g_list_free(list);
+  g_list_free_full(list, (GDestroyNotify) gtk_tree_path_free);
 }
 
 static void
@@ -559,8 +594,7 @@ SwitchDialogTop(GtkWidget *w, gpointer client_data)
   if (list) {
     num = g_list_length(list);
     g_list_foreach(list, switch_dialog_top_cb, d);
-    g_list_foreach(list, free_tree_path_cb, NULL);
-    g_list_free(list);
+    g_list_free_full(list, (GDestroyNotify) gtk_tree_path_free);
   }
   SwitchDialogSetupItem(d->widget, d);
   for (i = 0; i < num; i++) {
@@ -584,8 +618,7 @@ SwitchDialogLast(GtkWidget *w, gpointer client_data)
     num = g_list_length(list);
     list = g_list_reverse(list);
     g_list_foreach(list, switch_dialog_last_cb, d);
-    g_list_foreach(list, free_tree_path_cb, NULL);
-    g_list_free (list);
+    g_list_free_full(list, (GDestroyNotify) gtk_tree_path_free);
   }
   SwitchDialogSetupItem(d->widget, d);
   n = list_store_get_num(d->drawlist);
@@ -626,8 +659,7 @@ SwitchDialogRemove(GtkWidget *w, gpointer client_data)
   if (list) {
     list = g_list_reverse(list);
     g_list_foreach(list, switch_dialog_remove_cb, d);
-    g_list_foreach(list, free_tree_path_cb, NULL);
-    g_list_free (list);
+    g_list_free_full(list, (GDestroyNotify) gtk_tree_path_free);
   }
   SwitchDialogSetupItem(d->widget, d);
   set_drawlist_btn_state(d, FALSE);
@@ -922,6 +954,17 @@ DirectoryDialog(struct DirectoryDialog *data)
   data->CloseWindow = DirectoryDialogClose;
 }
 
+static void
+set_directory_name(GtkFileChooserButton *widget, gpointer user_data)
+{
+  char *path;
+  path = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(widget));
+  gtk_widget_set_tooltip_text(GTK_WIDGET(widget), path);
+  if (path) {
+    g_free(path);
+  }
+}
+
 static void
 LoadDialogSetup(GtkWidget *wi, void *data, int makewidget)
 {
@@ -931,18 +974,20 @@ LoadDialogSetup(GtkWidget *wi, void *data, int makewidget)
   if (makewidget) {
     GtkWidget *w, *vbox;
     int j;
-    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
+    vbox = gtk_grid_new();
 
     w = gtk_check_button_new_with_mnemonic(_("_Expand included file"));
     d->expand_file = w;
-    gtk_box_pack_start(GTK_BOX(vbox), w, FALSE, FALSE, 4);
+    gtk_grid_attach(GTK_GRID(vbox), w, 0, 0, 2, 1);
 
-    w = create_text_entry(FALSE, TRUE);
-    item_setup(vbox, w, _("_Dir:"), FALSE);
+    w = gtk_file_chooser_button_new(_("Expand directory"), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
+    gtk_file_chooser_set_local_only(GTK_FILE_CHOOSER(w), TRUE);
+    g_signal_connect(w, "file-set", G_CALLBACK(set_directory_name), NULL);
+    add_widget_to_table(vbox, w, _("expand _Directory:"), FALSE, 1);
     d->dir = w;
 
     w = combo_box_create();
-    item_setup(vbox, w, _("_Path:"), FALSE);
+    add_widget_to_table(vbox, w, _("_Path:"), FALSE, 2);
     for (j = 0; LoadPathStr[j]; j++) {
       combo_box_append_text(w, _(LoadPathStr[j]));
     }
@@ -953,22 +998,23 @@ LoadDialogSetup(GtkWidget *wi, void *data, int makewidget)
   }
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(d->expand_file), d->expand);
   combo_box_set_active(d->load_path, d->loadpath);
-  gtk_entry_set_text(GTK_ENTRY(d->dir), d->exdir);
+  gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(d->dir), d->exdir);
+  set_directory_name(GTK_FILE_CHOOSER_BUTTON(d->dir), NULL);
 }
 
 static void
 LoadDialogClose(GtkWidget *w, void *data)
 {
   struct LoadDialog *d;
-  const char *s;
 
   d = (struct LoadDialog *) data;
   if (d->ret == IDCANCEL)
     return;
   d->expand = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(d->expand_file));
-  s = gtk_entry_get_text(GTK_ENTRY(d->dir));
-  g_free(d->exdir);
-  d->exdir = g_strdup(s);
+  if (d->exdir) {
+    g_free(d->exdir);
+  }
+  d->exdir = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(d->dir));
   d->loadpath = combo_box_get_active(d->load_path);
 }
 
@@ -1060,6 +1106,7 @@ CmGraphNewMenu(void *w, gpointer client_data)
 
   DeleteDrawable();
 
+  CmGraphPage(NULL, GINT_TO_POINTER(TRUE));
   sel = GPOINTER_TO_INT(client_data);
   switch (sel) {
   case MenuIdGraphNewFrame:
@@ -1089,7 +1136,7 @@ CmGraphNewMenu(void *w, gpointer client_data)
 void
 CmGraphLoad(void *w, gpointer client_data)
 {
-  char *file;
+  char *file, *cwd;
 
   if (Menulock || Globallock)
     return;
@@ -1097,14 +1144,23 @@ CmGraphLoad(void *w, gpointer client_data)
   if (!CheckSave())
     return;
 
+  cwd = ngetcwd();
   if (nGetOpenFileName(TopLevel,
 		       _("Load NGP file"), "ngp", &(Menulocal.graphloaddir),
 		       NULL, &file, TRUE,
 		       Menulocal.changedirectory) != IDOK) {
+    if (cwd) {
+      g_free(cwd);
+    }
     return;
   }
 
-  LoadNgpFile(file, Menulocal.scriptconsole, "-f");
+  if (LoadNgpFile(file, Menulocal.scriptconsole, "-f") && cwd) {
+    nchdir(cwd);
+  }
+  if (cwd) {
+    g_free(cwd);
+  }
   g_free(file);
 }
 
@@ -1139,14 +1195,18 @@ CmGraphSwitch(void *w, gpointer client_data)
 void
 CmGraphPage(void *w, gpointer client_data)
 {
+  int new_graph;
+  new_graph = GPOINTER_TO_INT(client_data);
   if (Menulock || Globallock)
     return;
-  PageDialog(&DlgPage);
+  PageDialog(&DlgPage, new_graph);
   if (DialogExecute(TopLevel, &DlgPage) == IDOK) {
     SetPageSettingsToGRA();
     ChangePage();
     GetPageSettingsFromGRA();
-    set_graph_modified_gra();
+    if (! new_graph) {
+      set_graph_modified_gra();
+    }
   }
 }
 
@@ -1201,10 +1261,24 @@ CmGraphQuit(void *w, gpointer client_data)
   QuitGUI();
 }
 
+int
+chdir_to_ngp(const char *fname)
+{
+  char *path;
+  int r;
+  path = g_path_get_dirname(fname);
+  if (path == NULL) {
+    return 0;
+  }
+  r = nchdir(path);
+  g_free(path);
+  return r;
+}
+
 void
 CmGraphHistory(GtkRecentChooser *w, gpointer client_data)
 {
-  char *uri, *fname, *path;
+  char *uri, *fname, *cwd;
 
   if (Menulock || Globallock)
     return;
@@ -1225,16 +1299,22 @@ CmGraphHistory(GtkRecentChooser *w, gpointer client_data)
     return;
   }
 
-  path = g_path_get_dirname(fname);
-  if (nchdir(path)) {
+  cwd = ngetcwd();
+  if (chdir_to_ngp(fname)) {
     ErrorMessage();
-    g_free(path);
     g_free(fname);
+    if (cwd) {
+      g_free(cwd);
+    }
     return;
   }
-  g_free(path);
 
-  LoadNgpFile(fname, Menulocal.scriptconsole, "-f");
+  if (LoadNgpFile(fname, Menulocal.scriptconsole, "-f") && cwd) {
+    nchdir(cwd);
+  }
+  if (cwd) {
+    g_free(cwd);
+  }
   g_free(fname);
 }
 
