@@ -1110,10 +1110,74 @@ remove_child(GtkWidget *widget, gpointer data)
   gtk_container_remove(container, widget);
 }
 
+static void
+save_as_default(GtkButton *button, gpointer user_data)
+{
+  struct obj_list_data *d;
+  int i, num, type, modified, undo;
+  double parameter, value;
+  d = (struct obj_list_data *) user_data;
+  num = chkobjlastinst(d->obj) + 1;
+  modified = FALSE;
+  undo = menu_save_undo_single(UNDO_TYPE_EDIT, d->obj->name);
+  for (i = 0; i < num; i++) {
+    int ival;
+    getobj(d->obj, "type", i, 0, NULL, &type);
+    if (type == PARAMETER_TYPE_TRANSITION) {
+      continue;
+    }
+    getobj(d->obj, "parameter", i, 0, NULL, &parameter);
+    switch (type) {
+    case PARAMETER_TYPE_SPIN:
+    case PARAMETER_TYPE_SCALE:
+      getobj(d->obj, "value", i, 0, NULL, &value);
+      if (value != parameter) {
+	putobj(d->obj, "value", i, &parameter);
+	modified = TRUE;
+      }
+      break;
+    case PARAMETER_TYPE_SWITCH:
+    case PARAMETER_TYPE_CHECK:
+      getobj(d->obj, "active", i, 0, NULL, &ival);
+      if (ival != parameter) {
+	ival = parameter;
+	putobj(d->obj, "active", i, &ival);
+	modified = TRUE;
+      }
+      break;
+    case PARAMETER_TYPE_COMBO:
+      getobj(d->obj, "selected", i, 0, NULL, &ival);
+      if (ival != parameter) {
+	ival = parameter;
+	putobj(d->obj, "selected", i, &ival);
+	modified = TRUE;
+      }
+      break;
+    }
+  }
+  if (modified) {
+    set_graph_modified();
+  } else {
+    menu_delete_undo(undo);
+  }
+}
+
+static void
+add_save_as_default_button(struct obj_list_data *d, int row, int width)
+{
+  GtkWidget *button, *box;
+  button = gtk_button_new_with_mnemonic(_("_Save as default"));
+  g_signal_connect(button, "clicked", G_CALLBACK(save_as_default), d);
+
+  box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+  gtk_box_pack_start(GTK_BOX(box), button, FALSE, FALSE, 0);
+  gtk_grid_attach(GTK_GRID(d->text), box, 1, row, width, 1);
+}
+
 void
 ParameterWinUpdate(struct obj_list_data *d, int clear, int draw)
 {
-  int num, i, col;
+  int num, i, col, add_save_button;
 
   if (Menulock || Globallock)
     return;
@@ -1122,9 +1186,15 @@ ParameterWinUpdate(struct obj_list_data *d, int clear, int draw)
     return;
   }
 
+  add_save_button = FALSE;
   gtk_container_foreach(GTK_CONTAINER(d->text), remove_child, d->text);
   num = chkobjlastinst(d->obj);
   for (i = 0; i <= num; i++) {
+    int type;
+    getobj(d->obj, "type", i, 0, NULL, &type);
+    if (! add_save_button && (type != PARAMETER_TYPE_TRANSITION)) {
+      add_save_button = TRUE;
+    }
     col = create_widget(d, i, num);
   }
 
@@ -1135,6 +1205,9 @@ ParameterWinUpdate(struct obj_list_data *d, int clear, int draw)
     gtk_grid_attach(GTK_GRID(d->text), separator, 1, num, col - 4, 1);
   }
   add_button(d->text, num + 1, 0, "list-add-symbolic", _("Add"), G_CALLBACK(CmParameterAdd), NULL);
+  if (add_save_button) {
+    add_save_as_default_button(d, num + 1, col - 4);
+  }
 
   gtk_widget_show_all(GTK_WIDGET(d->text));
 }
