@@ -38,6 +38,7 @@
 #include "object.h"
 #include "nstring.h"
 #include "ioutil.h"
+#include "strconv.h"
 
 #ifndef O_BINARY
 #define O_BINARY 0
@@ -132,8 +133,7 @@ pathresolv(char *name)
 char *
 getfullpath(const char *name)
 {
-  char *s, *cwd, *utf8_name;
-  int top;
+  char *s, *utf8_name;
 
   if (name == NULL) {
     return NULL;
@@ -149,6 +149,7 @@ getfullpath(const char *name)
   if (utf8_name[0] == DIRSEP && utf8_name[1] == DIRSEP) {
     s = utf8_name;
   } else {
+    int top;
     if (isalpha(utf8_name[0]) && utf8_name[1] == ':') {
       top = 2;
     } else {
@@ -157,6 +158,7 @@ getfullpath(const char *name)
     if (utf8_name[top] == DIRSEP) {
       s = utf8_name;
     } else {
+      char *cwd;
       cwd = ngetcwd();
       if (cwd == NULL) {
 	g_free(utf8_name);
@@ -195,7 +197,6 @@ char *
 getrelativepath(const char *name)
 {
   char *utf8_name, *str;
-  GString *s;
 
   if (name == NULL) {
     return NULL;
@@ -210,7 +211,7 @@ getrelativepath(const char *name)
     str = utf8_name;
     pathresolv(str);
   } else {
-    int i, j, top, depth;
+    int top;
 
     top = 0;
 #if WINDOWS
@@ -225,7 +226,9 @@ getrelativepath(const char *name)
 	name[0] == DIRSEP
 #endif	/* WINDOWS */
 	) {
+      GString *s;
       char *cwd, *cwd2;
+      int i, j, depth;
 
       cwd = ngetcwd();
       if (cwd == NULL) {
@@ -315,7 +318,13 @@ get_utf8_filename(const char *name)
     utf8_name = g_filename_to_utf8(name, -1, NULL, NULL, NULL);
 #endif	/* WINDOWS */
   }
-
+  if (utf8_name == NULL) {
+    /* for compatibility with Ngraph for Windows */
+    utf8_name = sjis_to_utf8(name);
+  }
+  if (utf8_name == NULL) {
+    utf8_name = g_strdup(name);
+  }
   changefilename(utf8_name);
 
   return utf8_name;
@@ -452,7 +461,7 @@ ngetcwd(void)
 char *
 nsearchpath(char *path,char *name,int shellscript)
 {
-  char *cmdname,*tok;
+  char *cmdname;
   int len;
 
   if (name==NULL) return NULL;
@@ -464,6 +473,7 @@ nsearchpath(char *path,char *name,int shellscript)
   }
 
   if (strchr(name,DIRSEP)==NULL) {
+    char *tok;
     while ((tok=getitok(&path,&len,PATHSEP))!=NULL) {
       g_free(cmdname);
       if ((cmdname=g_malloc(strlen(name)+len+2))==NULL) return NULL;
@@ -554,9 +564,8 @@ nalphasort(char **a,char **b)
 static int
 nglob2(char *path,int po,int *num,char ***list)
 {
-  int i,j,p1,escape,scannum,len,err;
-  char *s,*s1,*s2,*s3,*path2;
-  char **namelist;
+  int i,j,p1,escape;
+  char **namelist, *s;
 
   if (path==NULL) return 0;
   p1=po;
@@ -582,6 +591,8 @@ nglob2(char *path,int po,int *num,char ***list)
       (*num)++;
     }
   } else {
+    int scannum,len,err;
+    char *s1,*s2,*s3,*path2;
     for (;(path[i]!='\0') && (path[i]!=DIRSEP);i++) ;
     s1 = g_malloc(p1 + 1);
     s2 = g_malloc(i - p1 + 1);
@@ -643,7 +654,6 @@ int
 nglob(char *path,char ***namelist)
 {
   int num;
-  char *s;
 
   *namelist=NULL;
   num=0;
@@ -652,10 +662,11 @@ nglob(char *path,char ***namelist)
     return -1;
   }
   if (num==0) {
-    if ((s=g_malloc(strlen(path)+1))==NULL) return -1;
-    strcpy(s,path);
+    char *s;
+    s = g_strdup(path);
+    if (s == NULL) return -1;
     if (arg_add(namelist,s)==NULL) return -1;
-    return 1;
+    num = 1;
   }
   return num;
 }
