@@ -5,10 +5,15 @@ IO.foreach(ARGV[0]) { |l|
   next if (l[0] == ?#)
   l.chomp!
   next if (l.length < 1)
-  func_str.push(l.split) 
+  func_str.push(l.split)
 }
 
 func_str = func_str.uniq.sort {|a, b| b[0].length - a[0].length}
+MathFunctionType = [
+  "MATH_FUNCTION_TYPE_NORMAL",
+  "MATH_FUNCTION_TYPE_POSITIONAL",
+  "MATH_FUNCTION_TYPE_CALLBACK",
+]
 
 File.open("#{ARGV[1]}.h", "w") { |f|
   f.puts <<EOF
@@ -17,15 +22,26 @@ File.open("#{ARGV[1]}.h", "w") { |f|
 
 enum MATH_FUNCTION_ARG_TYPE {
   MATH_FUNCTION_ARG_TYPE_DOUBLE,
+  MATH_FUNCTION_ARG_TYPE_STRING,
   MATH_FUNCTION_ARG_TYPE_ARRAY,
+  MATH_FUNCTION_ARG_TYPE_STRING_ARRAY,
+  MATH_FUNCTION_ARG_TYPE_ARRAY_COMMON,
+  MATH_FUNCTION_ARG_TYPE_VARIABLE,
+  MATH_FUNCTION_ARG_TYPE_STRING_VARIABLE,
+  MATH_FUNCTION_ARG_TYPE_VARIABLE_COMMON,
   MATH_FUNCTION_ARG_TYPE_PROC,
 };
 
+enum MATH_FUNCTION_TYPE {
+  #{MathFunctionType.join(', ')}
+};
+
 typedef int (* math_function) (MathFunctionCallExpression *exp, MathEquation *eq, MathValue *r);
 
 struct math_function_parameter {
   int argc;
-  int side_effect, positional;
+  int side_effect;
+  enum MATH_FUNCTION_TYPE type;
   math_function func;
   enum MATH_FUNCTION_ARG_TYPE *arg_type;
   MathExpression *opt_usr, *base_usr;
@@ -70,15 +86,16 @@ EOF
   func = []
   i = 0;
   func_str.each {|s|
+    type = MathFunctionType[s[3].to_i]
     if (s.length == 5)
-      f.puts("  {\"#{s[0].upcase}\", {#{s[1]}, #{s[2]}, #{s[3]}, math_func_#{s[0]}, NULL, NULL, NULL, NULL}},")
+      f.puts("  {\"#{s[0].upcase}\", {#{s[1]}, #{s[2]}, #{type}, math_func_#{s[0]}, NULL, NULL, NULL, NULL}},")
       if (s[4] != "NULL")
         func.push([i, s[4].split(","), s[0].upcase])
       end
       i += 1
     elsif (s.length == 6)
       f.puts("#ifdef HAVE_LIBGSL")
-      f.puts("  {\"#{s[0].upcase}\", {#{s[1]}, #{s[2]}, #{s[3]}, math_func_#{s[0]}, NULL, NULL, NULL, NULL}},")
+      f.puts("  {\"#{s[0].upcase}\", {#{s[1]}, #{s[2]}, #{type}, math_func_#{s[0]}, NULL, NULL, NULL, NULL}},")
       if (s[4] != "NULL")
         func.push([i, s[4].split(","), s[0].upcase])
       end
@@ -121,8 +138,20 @@ EOF
              when "0"
                  "MATH_FUNCTION_ARG_TYPE_DOUBLE;"
              when "1"
+                 "MATH_FUNCTION_ARG_TYPE_STRING;"
+             when "10"
                  "MATH_FUNCTION_ARG_TYPE_ARRAY;"
-             when "2"
+             when "11"
+                 "MATH_FUNCTION_ARG_TYPE_STRING_ARRAY;"
+             when "12"
+                 "MATH_FUNCTION_ARG_TYPE_ARRAY_COMMON;"
+             when "20"
+                 "MATH_FUNCTION_ARG_TYPE_VARIABLE;"
+             when "21"
+                 "MATH_FUNCTION_ARG_TYPE_STRING_VARIABLE;"
+             when "22"
+                 "MATH_FUNCTION_ARG_TYPE_VARIABLE_COMMON;"
+             when "30"
                  "MATH_FUNCTION_ARG_TYPE_PROC;"
              end
              )
