@@ -21,13 +21,15 @@
  *
  */
 
+#include "ofit.h"
+
 #define MPI 3.1415926535897932385
 #define MEXP1 2.71828182845905
 #define MEULER 0.57721566490153286
 #define N_EPSILON 1E-12
 
-typedef double vector[11];
-typedef vector matrix[11];
+typedef double vector[FIT_DIMENSION_MAX + 1];
+typedef vector matrix[FIT_DIMENSION_MAX + 1];
 
 double cutdown(double x);
 double nraise(double x);
