@@ -113,7 +113,7 @@ darrayput(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   local->modified = TRUE;
 
   num=*(int *)argv[2];
-  val=*(double *)argv[3];
+  val = arg_to_double(argv, 3);
   _getobj(obj,"@",inst,&array);
   num = oarray_get_index(array, num);
   if (num < 0) {
@@ -145,7 +145,7 @@ darrayadd(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   _getobj(obj, "_local", inst, &local);
   local->modified = TRUE;
 
-  val=*(double *)argv[2];
+  val = arg_to_double(argv, 2);
 
   array = oarray_get_array(obj, inst, sizeof(double));
   if (array==NULL) {
@@ -208,7 +208,7 @@ darrayins(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   local->modified = TRUE;
 
   num=*(int *)argv[2];
-  val=*(double *)argv[3];
+  val = arg_to_double(argv, 3);
 
   array = oarray_get_array(obj, inst, sizeof(double));
   if (array==NULL) {
@@ -235,7 +235,7 @@ darrayunshift(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **ar
   _getobj(obj, "_local", inst, &local);
   local->modified = TRUE;
 
-  val = * (double *) argv[2];
+  val = arg_to_double(argv, 2);
 
   array = oarray_get_array(obj, inst, sizeof(double));
   if (array == NULL) {
@@ -362,7 +362,6 @@ darrayjoin(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **a
   GString *str;
   int i, n;
   char *sep, *ptr;
-  double val;
   struct darray_local *local;
 
   _getobj(obj, "_local", inst, &local);
@@ -394,6 +393,7 @@ darrayjoin(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **a
   }
 
   for (i = 0; i < n; i++) {
+    double val;
     val = arraynget_double(array, i);
     g_string_append_printf(str, "%.15e%s", val, (i == n - 1) ? "" : sep);
   }
@@ -410,7 +410,7 @@ cache_data(struct objlist *obj, N_VALUE *inst, struct darray_local *local)
 {
   struct narray *array;
   double min, max, sum, ssum, *data;
-  int i, n;
+  int n;
 
   _getobj(obj, "@", inst, &array);
   n = arraynum(array);
@@ -420,6 +420,7 @@ cache_data(struct objlist *obj, N_VALUE *inst, struct darray_local *local)
   sum = 0;
   ssum = 0;
   if (n > 0) {
+    int i;
     min = max = data[0];
     for (i = 0; i < n; i++) {
       sum += data[i];
