@@ -84,6 +84,10 @@ enum FONT_STYLE {
 #define DEFAULT_LINE_WIDTH   40
 #define DEFAULT_MARK_SIZE   200
 #define DEFAULT_FONT_PT    2000
+#define DEFAULT_SCRIPT_SIZE 7000
+
+#define SCRIPT_SIZE_MIN 1000
+#define SCRIPT_SIZE_MAX 100000
 
 extern char *pathchar[];
 extern char *joinchar[];
@@ -100,5 +104,6 @@ int put_stroke_hsb(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc,
 int put_hsb(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv);
 int put_hsb2(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv);
 int curve_expand_points(int *pdata, int num, int intp, struct narray *expand_points);
+void text_get_bbox(int x, int y, char *text, char *font, int style, int pt, int dir, int space, int scriptsize, int raw, int *bbox);
 
 #endif
