@@ -96,7 +96,7 @@ static char *fittypechar[]={
 
 struct fitlocal {
   int id, oid;
-  MathEquation *codedf[10];
+  MathEquation *codedf[FIT_DIMENSION_MAX];
   MathEquation *codef, *result_code;
   int dim;
   double coe[11];
@@ -127,7 +127,7 @@ fitinit(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   if ((fitlocal=g_malloc(sizeof(struct fitlocal)))==NULL) return 1;
   fitlocal->codef=NULL;
   fitlocal->result_code = NULL;
-  for (i=0;i<10;i++) fitlocal->codedf[i]=NULL;
+  for (i=0;i<FIT_DIMENSION_MAX;i++) fitlocal->codedf[i]=NULL;
   fitlocal->equation=NULL;
   fitlocal->oid = oid;
   if (_putobj(obj,"_local",inst,fitlocal)) {
@@ -148,7 +148,7 @@ fitdone(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   g_free(fitlocal->equation);
   math_equation_free(fitlocal->codef);
   math_equation_free(fitlocal->result_code);
-  for (i = 0; i < 10; i++)
+  for (i = 0; i < FIT_DIMENSION_MAX; i++)
     math_equation_free(fitlocal->codedf[i]);
   return 0;
 }
@@ -250,7 +250,7 @@ fitput(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,
   field=argv[1];
   if (strcmp(field,"poly_dimension")==0) {
     if (*(int *)(argv[2])<1) *(int *)(argv[2])=1;
-    else if (*(int *)(argv[2])>9) *(int *)(argv[2])=9;
+    else if (*(int *)(argv[2])>=FIT_DIMENSION_MAX) *(int *)(argv[2])=FIT_DIMENSION_MAX - 1;
   } else if ((strcmp(field,"user_func")==0)
           || ((strncmp(field,"derivative",10)==0) && (field[10]!='\0'))) {
     math=(char *)(argv[2]);
@@ -267,7 +267,7 @@ fitput(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,
 	return 1;
       }
 
-      if (prm->id_max > 9) {
+      if (prm->id_max >= FIT_DIMENSION_MAX) {
         error(obj,ERRMANYPARAM);
 	math_equation_free(code);
         return 1;
@@ -519,7 +519,7 @@ fitpoly(struct fitlocal *fitlocal,
   derror=sqrt(derror);
   if (through) dim--;
   for (i=0;i<dim;i++) fitlocal->coe[i]=coe[i];
-  for (;i<10;i++) fitlocal->coe[i]=0;
+  for (;i<FIT_DIMENSION_MAX;i++) fitlocal->coe[i]=0;
   fitlocal->dim=dim;
   fitlocal->derror=derror;
   fitlocal->correlation=correlation;
@@ -664,10 +664,10 @@ fituser(struct objlist *obj,struct fitlocal *fitlocal, const char *func,
 {
   int ecode;
   int *needdata;
-  int tbl[10],dim,n,count,err,err2,err3;
+  int tbl[FIT_DIMENSION_MAX],dim,n,count,err,err2,err3;
   double yy,y,y1,y2,y3,sy,spx,spy,dxx,dxxc,xx,derror,correlation;
-  double b[10],x2[10],parerr[10];
-  MathValue par[10], par2[10], var;
+  vector b, x2, parerr;
+  MathValue par[FIT_DIMENSION_MAX], par2[FIT_DIMENSION_MAX], var;
   MathEquationParametar *prm;
   matrix m;
   int i,j,k;
@@ -691,7 +691,7 @@ fituser(struct objlist *obj,struct fitlocal *fitlocal, const char *func,
     }
   }
   for (i = 0; i < dim; i++) tbl[i] = needdata[i];
-  for (i = 0; i < 10; i++) {
+  for (i = 0; i < FIT_DIMENSION_MAX; i++) {
     par[i].type = MATH_VALUE_NORMAL;
     par[i].val = fitlocal->coe[i];
   }
@@ -771,7 +771,7 @@ fituser(struct objlist *obj,struct fitlocal *fitlocal, const char *func,
         }
       } else {
         for (j=0;j<dim;j++) {
-          for (i=0;i<10;i++) par2[i]=par[i];
+          for (i=0;i<FIT_DIMENSION_MAX;i++) par2[i]=par[i];
           dxx = par2[j].val * converge * 1e-6;
           if (dxx == 0) dxx = 1e-6;
           par2[tbl[j]].val += dxx;
@@ -917,7 +917,7 @@ repeat:
 
 errexit:
   if ((ecode==FitError_Success) || (ecode==FitError_Range)) {
-    for (i = 0; i < 10; i++) {
+    for (i = 0; i < FIT_DIMENSION_MAX; i++) {
       fitlocal->coe[i] = par[i].val;
     }
     fitlocal->dim=dim;
@@ -964,7 +964,7 @@ fitfit(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   if (_putobj(obj,"error",inst,&derror)) return 1;
   if (_putobj(obj,"correlation",inst,&correlation)) return 1;
 
-  for (i = 0; i < 10; i++) {
+  for (i = 0; i < FIT_DIMENSION_MAX; i++) {
     snprintf(prm, sizeof(prm), "%%%02d", i);
     if (_putobj(obj, prm, inst, &pp)) return 1;
   }
@@ -980,7 +980,7 @@ fitfit(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   _getobj(obj,"converge",inst,&converge);
   _getobj(obj, "id", inst, &(fitlocal->id));
 
-  for (i = 0; i < 10; i++) {
+  for (i = 0; i < FIT_DIMENSION_MAX; i++) {
     snprintf(prm, sizeof(prm), "parameter%d", i);
     _getobj(obj, prm, inst, &(fitlocal->coe[i]));
   }
@@ -1133,7 +1133,7 @@ fitfit(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   if (_putobj(obj,"error",inst,&(fitlocal->derror))) return 1;
   if (_putobj(obj,"correlation",inst,&(fitlocal->correlation))) return 1;
 
-  for (i = 0; i < 10; i++) {
+  for (i = 0; i < FIT_DIMENSION_MAX; i++) {
     snprintf(prm, sizeof(prm), "%%%02d", i);
     if (_putobj(obj, prm, inst, &(fitlocal->coe[i]))) return 1;
   }
@@ -1207,7 +1207,11 @@ fit_inst_dup(struct objlist *obj, N_VALUE *src, N_VALUE *dest)
     return 1;
   }
   local_src = src[pos].ptr;
+#if GLIB_CHECK_VERSION(2, 68, 0)
+  local_new = g_memdup2(local_src, sizeof(struct fitlocal));
+#else
   local_new = g_memdup(local_src, sizeof(struct fitlocal));
+#endif
   if (local_new == NULL) {
     return 1;
   }
@@ -1222,7 +1226,7 @@ fit_inst_dup(struct objlist *obj, N_VALUE *src, N_VALUE *dest)
     }
   }
   len = sizeof(deriv);
-  for (i = 0; i < 10; i++) {
+  for (i = 0; i < FIT_DIMENSION_MAX; i++) {
     deriv[len - 2] = '0' + i;
     if (local_src->codedf[i]) {
       _getobj(obj, deriv, src, &math);
@@ -1255,7 +1259,7 @@ fit_inst_free(struct objlist *obj, N_VALUE *inst)
   if (local->codef) {
     math_equation_free(local->codef);
   }
-  for (i = 0; i < 10; i++) {
+  for (i = 0; i < FIT_DIMENSION_MAX; i++) {
     if (local->codedf[i]) {
       math_equation_free(local->codedf[i]);
     }
