@@ -39,6 +39,7 @@
 #include "ioutil.h"
 #include "mathfn.h"
 #include "shell.h"
+#include "shell_error.h"
 #include "shellcm.h"
 
 #include "math/math_equation.h"
@@ -88,7 +89,6 @@ cmecho(struct nshell *nshell,int argc,char **argv)
 int
 cmbasename(struct nshell *nshell,int argc,char **argv)
 {
-  int len, ext_len;
   char *bname;
 
   if (argc < 2) {
@@ -104,9 +104,8 @@ cmbasename(struct nshell *nshell,int argc,char **argv)
     return 1;
   }
 
-  if (argc == 2) {
-    len = strlen(bname);
-  } else {
+  if (argc > 2) {
+    int len, ext_len;
     len = strlen(bname);
     ext_len = strlen(argv[2]);
 
@@ -267,11 +266,11 @@ printexp(struct nhash *h, void *data)
 int
 cmexport(struct nshell *nshell,int argc,char **argv)
 {
-  int i;
 #if USE_HASH
   if (argv[1] == NULL) {
     nhash_each(nshell->exproot, printexp, NULL);
   } else {
+    int i;
     for (i = 1; i < argc; i++) {
       if (addexp(nshell, argv[i]) == NULL)
 	return ERR;
@@ -289,6 +288,7 @@ cmexport(struct nshell *nshell,int argc,char **argv)
     }
     return 0;
   } else {
+    int i;
     for (i=1;i<argc;i++)
       if (addexp(nshell,argv[i])==NULL) return ERR;
     return 0;
@@ -559,11 +559,12 @@ cmtype(struct nshell *nshell,int argc,char **argv)
 {
   struct prmlist *prm2;
   struct cmdlist *cmdcur;
-  int i,j;
+  int j;
   char *cmdname;
   shell_proc proc;
 
   for (j=1;j<argc;j++) {
+    int i;
     i = check_cpcmd(argv[j]);
     if (i >= 0) {
       printfstdout("%.256s is a shell keyword.\n", argv[j]);
@@ -647,7 +648,6 @@ dispfield(struct objlist *obj,char *name)
   int j;
   enum ngraph_object_field_type ftype;
   char perm[4],type[10];
-  const char *alist;
   char **enumlist;
 
   ftype=chkobjfieldtype(obj,name);
@@ -692,6 +692,7 @@ dispfield(struct objlist *obj,char *name)
   printfstdout("%3s %16.256s  %.256s",
                    (char *)perm,(char *)name,(char *)type);
   if (ftype>=NVFUNC) {
+    const char *alist;
     if ((alist=chkobjarglist(obj,name))!=NULL) {
       if (alist[0]=='\0') printfstdout(" void");
       else
@@ -728,7 +729,6 @@ cmobject(struct nshell *nshell,int argc,char **argv)
 {
   struct objlist *obj;
   int i,j,tab;
-  char *name;
 
   if (argc<2) {
     tab=0;
@@ -754,6 +754,7 @@ cmobject(struct nshell *nshell,int argc,char **argv)
     printfstdout("current instance: %d\n",chkobjcurinst(obj));
     printfstdout("last instance id: %d\n",chkobjlastinst(obj));
     for (i=0;i<chkobjfieldnum(obj);i++) {
+      char *name;
       name=chkobjfieldname(obj,i);
       dispfield(obj,name);
     }
@@ -989,7 +990,7 @@ cmget(struct nshell*nshell,int argc,char **argv)
   struct objlist *obj;
   struct narray iarray;
   char *field,*valstr;
-  int i,j,k,l,id,anum,len,*adata;
+  int i,j,k,l,anum,len,*adata;
   int nowrite,nofield,noid,quote,perm,multi,escape;
 
   if (argc<2) {
@@ -1027,6 +1028,7 @@ cmget(struct nshell*nshell,int argc,char **argv)
   if (anum==1) multi=FALSE;
   else multi=TRUE;
   for (l=0;l<anum;l++) {
+    int id;
     id=adata[l];
     if (j==argc) {
       for (i=0;i<chkobjfieldnum(obj);i++) {
@@ -1076,7 +1078,7 @@ int
 cmput(struct nshell*nshell,int argc,char **argv)
 {
   struct objlist *obj;
-  int i,j,id,anum,*adata;
+  int i,j,anum,*adata;
   struct narray iarray;
 
   if (argc<2) {
@@ -1098,6 +1100,7 @@ cmput(struct nshell*nshell,int argc,char **argv)
     return ERRNOFIELD;
   }
   for (i=0;i<anum;i++) {
+    int id;
     id=adata[i];
     for (j=2;j<argc;j++) {
       if (sputfield(obj,id,argv[j])!=0) {
@@ -1115,7 +1118,7 @@ cmdup(struct nshell *nshell, int argc, char **argv)
 {
   struct objlist *obj;
   struct narray iarray;
-  int i, anum, sid, did, *adata;
+  int i, anum, *adata;
 
   if (argc < 2) {
     sherror4(argv[0], ERROBJARG);
@@ -1136,6 +1139,7 @@ cmdup(struct nshell *nshell, int argc, char **argv)
   }
 
   for (i = 0; i < anum; i++) {
+    int sid, did;
     sid = adata[i];
     did = newobj(obj);
     if (did < 0) {
@@ -1158,7 +1162,7 @@ cmcpy(struct nshell*nshell,int argc,char **argv)
 {
   struct objlist *obj;
   struct narray iarray;
-  int i,j,anum,sid,did,*adata;
+  int i,j,anum,*adata;
 
   if (argc<2) {
     sherror4(argv[0],ERROBJARG);
@@ -1174,6 +1178,7 @@ cmcpy(struct nshell*nshell,int argc,char **argv)
     return ERRTWOINST;
   }
   for (i=1;i<anum;i++) {
+    int sid, did;
     sid=adata[0];
     did=adata[i];
     if (argc == 2) {
@@ -1269,7 +1274,7 @@ cmexe(struct nshell*nshell,int argc,char **argv)
 {
   struct objlist *obj;
   struct narray iarray;
-  int i,j,id,anum,*adata;
+  int i,j,anum,*adata;
 
   if (argc<2) {
     sherror4(argv[0],ERROBJARG);
@@ -1290,6 +1295,7 @@ cmexe(struct nshell*nshell,int argc,char **argv)
     return ERRNOFIELD;
   }
   for (j=0;j<anum;j++) {
+    int id;
     id=adata[j];
     for (i=2;i<argc;i++) {
       if (sexefield(obj,id,argv[i])!=0) {
@@ -1358,8 +1364,8 @@ cmdexpr(struct nshell*nshell,int argc,char **argv)
 int
 cmread(struct nshell *nshell,int argc,char **argv)
 {
-  int c,i,len;
-  char *po,*s2,*ifs;
+  int c,len;
+  char *po;
   GString *s;
 
   s = g_string_sized_new(64);
@@ -1378,9 +1384,12 @@ cmread(struct nshell *nshell,int argc,char **argv)
   if (argc == 1) {
     addval(nshell, "REPLY", s->str);
   } else {
+    char *ifs;
+    int i;
     po = s->str;
     ifs = getval(nshell, "IFS");
     for (i = 1; i < argc; i++) {
+      char *s2;
       s2 = getitok2(&po, &len, ifs);
       if (s2) {
         addval(nshell, argv[i], s2);
